@@ -526,7 +526,7 @@ class VariableOsLocaleLatSet(ReadonlyVariable, Locale):
     def get(self):
         """xkb layouts (example: en,ru)"""
         layout = self.Get('os_locale_xkbname').split(',')
-        if layout == 1:
+        if len(layout) == 1:
             return "on"
         else:
             return "off"
